@@ -13,7 +13,7 @@
 #' @export
 lesy  <- function() {
 
-  remote_path <- 'http://rczechia.jla-data.net/'
+  remote_path <- 'https://rczechia.jla-data.net/'
 
   file <- 'Lesy.rds'
 
@@ -26,14 +26,14 @@ lesy  <- function() {
 
   } else {
 
-    if (http_error(remote_file)) {
+    if (httr::http_error(remote_file)) {
 
       stop('No internet connection or data source broken.')
 
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      curl_download(url = remote_file, destfile = local_file, quiet = T)    }
+      curl::curl_download(url = remote_file, destfile = local_file, quiet = T)    }
   }
 
   local_df <- readRDS(local_file)
