@@ -18,7 +18,7 @@
 
 silnice <- function() {
 
-  remote_path <- 'http://rczechia.jla-data.net/'
+  remote_path <- 'https://rczechia.jla-data.net/'
 
   file <- 'Silnice.rds'
 
@@ -31,14 +31,14 @@ silnice <- function() {
 
   } else {
 
-    if (http_error(remote_file)) {
+    if (httr::http_error(remote_file)) {
 
       stop('No internet connection or data source broken.')
 
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      curl_download(url = remote_file, destfile = local_file, quiet = T)
+      curl::curl_download(url = remote_file, destfile = local_file, quiet = T)
 
       }
   }
